@@ -51,6 +51,15 @@ yearweek.NULL <- function(x,
   new_yearweek(double(), week_start = week_start)
 }
 
+#' @export
+yearweek.logical <- function(x, ...) {
+  if (is.logical(x) && all(is.na(x))) {
+    new_yearweek(0) + NA_real_
+  } else {
+    dont_know(x, "yearweek")
+  }
+}
+
 #' @export
 yearweek.numeric <- function(x,
                              week_start = getOption("lubridate.week.start", 1)) {
